@@ -3,6 +3,7 @@ package Perl::PrereqScanner::NotQuiteLite::App;
 use strict;
 use warnings;
 use File::Find;
+use File::Glob 'bsd_glob';
 use File::Basename;
 use File::Spec;
 use CPAN::Meta::Prereqs;
@@ -47,7 +48,7 @@ sub new {
       my ($identifier, $description, $paths) = split ':', $spec;
       $map{$identifier} = {
         description => $description,
-        paths => [split ',', $paths],
+        paths => [map { bsd_glob(File::Spec->catdir($opts{base_dir}, $_)) } split ',', $paths],
       };
     }
     $opts{features} = \%map;
@@ -106,12 +107,17 @@ sub run {
     }
 
     # extra libs
-    push @args, @{$self->{libs} || []};
+    push @args, map { bsd_glob(File::Spec->catdir($self->{base_dir}, $_)) } @{$self->{libs} || []};
 
     # for develop requires
     push @args, "xt", "author" if $self->{develop};
   }
 
+  if ($self->{verbose}) {
+    print STDERR "Scanning the following files/directories\n";
+    print STDERR "  $_\n" for sort @args;
+  }
+
   for my $path (@args) {
     my $item = File::Spec->file_name_is_absolute($path) ? $path : File::Spec->catfile($self->{base_dir}, $path);
     -d $item ? $self->_scan_dir($item) :
@@ -158,6 +164,8 @@ sub run {
   $self->{prereqs};
 }
 
+sub index { shift->{index} }
+
 sub _print_prereqs {
   my $self = shift;
 
@@ -234,7 +242,11 @@ sub _exclude_local_modules {
   my $private_re = $self->{private_re};
   for my $req ($self->_requirements) {
     for my $module ($req->required_modules) {
-      $req->clear_requirement($module) if $self->{possible_modules}{$module} or ($private_re and $module =~ /$private_re/);
+      next unless $self->{possible_modules}{$module} or ($private_re and $module =~ /$private_re/);
+      $req->clear_requirement($module);
+      if ($self->{verbose}) {
+        print STDERR "  excluded $module (local)\n";
+      }
     }
   }
 }
@@ -268,7 +280,11 @@ sub _exclude_core_prereqs {
           !Module::CoreList::deprecated_in($module, undef, $perl_version)
       ) {
         my $core_version = $Module::CoreList::version{$perl_version}{$module} or next;
-        $req->clear_requirement($module) if $req->accepts_module($module => $core_version);
+        next unless $req->accepts_module($module => $core_version);
+        $req->clear_requirement($module);
+        if ($self->{verbose}) {
+          print STDERR "  excluded $module ($perl_version core)\n";
+        }
       }
     }
   }
@@ -362,10 +378,13 @@ sub _dedupe_indexed_prereqs {
         my $length = length $module;
         $score{$module} = join ".", ($depth || 0), $length;
       }
-      my $topmost = (sort {$score{$a} <=> $score{$b}} @modules_without_version)[0];
+      my $topmost = (sort {$score{$a} <=> $score{$b} or $a cmp $b} @modules_without_version)[0];
       for my $module (@modules_without_version) {
         next if $topmost eq $module;
         $req->clear_requirement($module);
+        if ($self->{verbose}) {
+          print STDERR "  deduped $module (in favor of $topmost)\n";
+        }
       }
     }
   }
@@ -400,6 +419,7 @@ sub _scan_file {
     parsers => $self->{parsers},
     recommends => $self->{recommends},
     suggests => $self->{suggests},
+    verbose => $self->{verbose},
   )->scan_file($file);
 
   my $relpath = File::Spec->abs2rel($file, $self->{base_dir});
@@ -409,7 +429,7 @@ sub _scan_file {
   if ($self->{features}) {
     for my $identifier (keys %{$self->{features}}) {
       my $feature = $self->{features}{$identifier};
-      if (grep {$relpath =~ m!^$_(?:/|$)!} @{$feature->{paths}}) {
+      if (grep {$file =~ m!^$_(?:/|$)!} @{$feature->{paths}}) {
         $prereqs = $feature->{prereqs} ||= CPAN::Meta::Prereqs->new;
         last;
       }
@@ -611,6 +631,10 @@ traverses files and directories and returns a L<CPAN::Meta::Prereqs>
 object that keeps all the requirements/suggestions, without printing
 anything unless you explicitly pass a C<print> option to C<new>.
 
+=head2 index
+
+returns a L<CPAN::Common::Index> backend object (if any).
+
 =head1 AUTHOR
 
 Kenichi Ishigaki, E<lt>ishigaki@cpan.orgE<gt>
